#!/esdata/env/dpn06xsu/job/bin/convsh

#  Convsh script conv2nc.tcl
#
#  Originally by Jeff Cole
#  Modified my Dave Sproson, June 2010
#  
#  Converts multiple output files into a single netcdf file. Optionally select only
#  certain fields
#
#  Usage:
#	conv2nc.tcl -i my/input/files* [-d 0 1 .. N] -o my/output/file.nc
#
#  Command line arguments:
#      -i input files (can be more than one file)
#      -d fields to include in combined netCDF file (integers)
#      -o output file (single file only)

#  Write out Netcdf file
set outformat netcdf

#  Automatically work out input file type
set filetype 0

#  Convert all fields in input files to Netcdf
set fieldlist -1

#  Get command line arguments:
#      -i input files (can be more than one file)
#      -d fields to include in combined netCDF file (integers)
#      -o output file (single file only)

set i false
set o false
set d false 
foreach arg $argv {
   switch -glob -- $arg {
      -i      {set i true ; set o false ; set d false}
      -o      {set i false ; set o true ; set d false}
      -d      {set i false ; set o false ; set d true}
      -*      {puts "unknown option $arg" ; set i false; set o false ; set d false}
      default {
         if {$i} {
            set infile [lappend infile $arg]
         } elseif {$o} {
            set outfile [lappend outfile $arg]
	 } elseif {$d} {
	    set fl [lappend fl $arg]
         } else {
            puts "unknown option $arg"
         }
      }
   }
}

if { [info exists fl] }  {
  set fieldlist $fl
}

if {! [info exists infile]} {
   puts "input file name must be given"
   exit
}

if {[info exists outfile]} {
   if {[llength $outfile] > 1} {
      set outfile [lindex $outfile 0]
      puts "Only one output file can be specified, using $outfile"
   }
} else {
   puts "output file name must be given"
   exit
}

#  Read in each of the input files

foreach file $infile {
   readfile $filetype $file
}



#  Write out all input fields to a single Netcdf file

writefile $outformat $outfile $fieldlist
